@@ -3,10 +3,10 @@ getPImps<-function(ltree,type){
 		return(NULL)
 	if(type==1 && all(ltree$trees$pick==0))
 		return(NULL)
-	if (type == 4 && any(ltree$trees$conc + ltree$trees$pick == 1) || 
+	if (any(ltree$trees$conc + ltree$trees$pick == 1) || 
         		any(ltree$trees$knot[ltree$trees$conc == 3] == 0)){
+		warning("A model was deleted due to a bug in the greedy search in logreg.")
 		return(NULL)
-		warning("Models deleted due to bug in Greedy search in logreg.")
 	}
 	mat.truth<-generateTruthTab(ltree)
 	truth<-ifelse(ltree$coef>=0 | is.na(ltree$coef),1,0)
